Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1432)

Unified Diff: content/browser/renderer_host/input/synthetic_gesture_controller.cc

Issue 1408213002: Add hooks for flushing input from BeginFrame dispatch on Aura (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix build for real Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/renderer_host/input/synthetic_gesture_controller.cc
diff --git a/content/browser/renderer_host/input/synthetic_gesture_controller.cc b/content/browser/renderer_host/input/synthetic_gesture_controller.cc
index 536426b71db2eed3f0df1476de222bc7b89d1a35..8b9962aba1153a4885b70d2b1e5acc1c1b0a4d81 100644
--- a/content/browser/renderer_host/input/synthetic_gesture_controller.cc
+++ b/content/browser/renderer_host/input/synthetic_gesture_controller.cc
@@ -49,14 +49,14 @@ void SyntheticGestureController::Flush(base::TimeTicks timestamp) {
}
// It's possible that all events generated by the gesture have been fully
// dispatched at this point, in which case |OnDidFlushInput()| was called
// before |pending_gesture_result_| was initialized. Requesting another flush
// will trigger the necessary gesture-ending call to |OnDidFlushInput()|.
pending_gesture_result_.reset(new SyntheticGesture::Result(result));
gesture_target_->SetNeedsFlush();
}
-void SyntheticGestureController::OnDidFlushInput() {
+void SyntheticGestureController::OnDidFlushAllInput() {
if (!pending_gesture_result_)
return;
@@ -49,14 +49,14 @@ void SyntheticGestureController::Flush(base::TimeTicks timestamp) {
}
// It's possible that all events generated by the gesture have been fully
- // dispatched at this point, in which case |OnDidFlushInput()| was called
+ // dispatched at this point, in which case |OnDidFlushAllInput()| was called
// before |pending_gesture_result_| was initialized. Requesting another flush
@@ -49,14 +49,14 @@ void SyntheticGestureController::Flush(base::TimeTicks timestamp) {
// before |pending_gesture_result_| was initialized. Requesting another flush
- // will trigger the necessary gesture-ending call to |OnDidFlushInput()|.
+ // will trigger the necessary gesture-ending call to |OnDidFlushAllInput()|.
pending_gesture_result_.reset(new SyntheticGesture::Result(result));
gesture_target_->SetNeedsFlush();

Powered by Google App Engine
This is Rietveld 408576698